@@ -1,8 +1,8 @@
 from logging.handlers import RotatingFileHandler
 import logging
-from configuration.LoggingConstants import LoggingConstants
+from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 import sys
-from CreateLoggerController import CreateLoggerController
+from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
 logger = CreateLoggerController("SendDataController").getLogger()
 loggingConstants = LoggingConstants()
 
